Form
=======================

.. currentmodule:: enaml.widgets.form

.. autoclass:: Form


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_form.QtForm
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_form.QtForm

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_form.WXForm
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_form.WXForm
